﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Drawing;
using System.Windows.Forms;

namespace ScrollProject
{
    public partial class Form1 : Form
    {
        private DataTable dt = new DataTable();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            string connectionString = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" +
           System.IO.Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments),
           @"ComponentOne Samples\Common\C1NWind.mdb") + ";";
            OleDbConnection conn = new OleDbConnection(connectionString);
            OleDbDataAdapter adapter = new OleDbDataAdapter("Select * from Cars", conn);
            adapter.Fill(dt);
            c1FlexGrid1.DataSource = dt;

            c1VScrollBar1.Minimum = 0;
            c1VScrollBar1.Maximum = CalculateVerticalScrollBarMaximum();
            c1HScrollBar1.Minimum = 0;
            c1HScrollBar1.Maximum = CalculateHorizontalScrollBarMaximum();

            c1VScrollBar1.Scroll += C1VScrollBar1_Scroll;
            c1HScrollBar1.Scroll += C1HScrollBar1_Scroll;

            c1FlexGrid1.AfterScroll += C1FlexGrid1_AfterScroll;

            c1FlexGrid1.AllowDelete = true;

            c1FlexGrid1.SizeChanged += C1FlexGrid1_SizeChanged;
        }

        private void C1FlexGrid1_SizeChanged(object sender, EventArgs e)
        {
            c1VScrollBar1.Maximum = CalculateVerticalScrollBarMaximum();
            c1HScrollBar1.Maximum = CalculateHorizontalScrollBarMaximum();
        }

        private int CalculateVerticalScrollBarMaximum()
        {
            var contentHeight = c1FlexGrid1.Rows[c1FlexGrid1.Rows.Count - 1].Bottom;
            var scrollPageHeight = c1FlexGrid1.ClientSize.Height;

            return contentHeight - scrollPageHeight + SystemInformation.HorizontalScrollBarHeight / 2 + 1;
        }

        private int CalculateHorizontalScrollBarMaximum()
        {
            var contentWidth = c1FlexGrid1.Cols[c1FlexGrid1.Cols.Count - 1].Right;
            var scrollPageWidth = c1FlexGrid1.ClientSize.Width;

            return contentWidth - scrollPageWidth + SystemInformation.VerticalScrollBarWidth / 2 + 1;
        }

        private void C1FlexGrid1_AfterScroll(object sender, C1.Win.C1FlexGrid.RangeEventArgs e)
        {
            var yPos = -c1FlexGrid1.ScrollPosition.Y;
            if (c1VScrollBar1.Minimum <= yPos && yPos <= c1VScrollBar1.Maximum)
            {
                c1VScrollBar1.Value = yPos;
            }

            var xPos = -c1FlexGrid1.ScrollPosition.X;
            if (c1HScrollBar1.Minimum <= xPos && xPos <= c1HScrollBar1.Maximum)
            {
                c1HScrollBar1.Value = xPos;
            }
        }

        private void C1VScrollBar1_Scroll(object sender, ScrollEventArgs e)
        {
            c1FlexGrid1.ScrollPosition = new Point(c1FlexGrid1.ScrollPosition.X, -e.NewValue);
        }

        private void C1HScrollBar1_Scroll(object sender, ScrollEventArgs e)
        {
            c1FlexGrid1.ScrollPosition = new Point(-e.NewValue, c1FlexGrid1.ScrollPosition.Y);
        }
    }
}
